# Development Documentation

Guides for developing with FraiseQL.

## Guides

- [Style Guide](/docs/development/style-guide.md) - Code and documentation standards
- [Link Best Practices](/docs/development/link-best-practices.md) - Documentation linking guidelines
- [Framework Submission Guide](/docs/development/FRAMEWORK_SUBMISSION_GUIDE.md) - Submit to framework lists
- [New User Confusions](/docs/development/NEW_USER_CONFUSIONS.md) - Common pain points
- [Philosophy](/docs/development/PHILOSOPHY.md) - Design principles

## Topics

- Development Setup
- Testing
- Debugging
- Contributing

## Related

- [Contributing Guide](/CONTRIBUTING.md)
- [Examples](/examples/)
- [Core Concepts](/docs/core/)
